import React, { useEffect, useState } from "react";
import SidePannel from "../components/layout/Dashboard/SidePannel";
import DashboardHome from "../components/layout/Dashboard/DashboardHome";
import DashboardProjects from "../components/layout/Dashboard/DashboardProjects";
import DashboardTrash from "../components/layout/Dashboard/DashboardTrash";
import {
  useOrganization,
  useSocketStore,
  useUserName,
} from "../store/builder/store";
import { getUserData } from "../components/layout/Dashboard/functions/getUserData";
import DashboardTutorial from "../components/layout/Dashboard/DashboardTutorial";

const Dashboard: React.FC = () => {
  const [activeTab, setActiveTab] = useState<string>("Home");
  const { setUserName } = useUserName();
  const { setOrganization } = useOrganization();
  const { userId, organization, email, userName } = getUserData();
  useEffect(() => {
    if (email) {
      useSocketStore.getState().initializeSocket(email, organization, userId);
      if (organization && userName) {
        setOrganization(organization);
        setUserName(userName);
      }
    }
  }, []);
  return (
    <div className="dashboard-main">
      <SidePannel setActiveTab={setActiveTab} activeTab={activeTab} />
      {activeTab == "Home" && <DashboardHome />}
      {activeTab == "Projects" && <DashboardProjects />}
      {activeTab == "Trash" && <DashboardTrash />}
      {activeTab == "Tutorials" && <DashboardTutorial />}
    </div>
  );
};

export default Dashboard;
